==> fast_rsa-1.1.4.tar.gz: example/lib/encrypt_decrypt_oaep_bytes.dart <==
import 'dart:convert';
import 'dart:typed_data';

import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:fast_rsa/rsa.dart';
import 'package:rsa_example/main.dart';
import 'package:rsa_example/shared/button_widget.dart';
import 'package:rsa_example/shared/input_widget.dart';
import 'package:rsa_example/shared/title_widget.dart';

class EncryptAndDecryptOAEPBytes extends StatefulWidget {
  const EncryptAndDecryptOAEPBytes({
    Key key,
    @required this.title,
    @required PKCS12KeyPair keyPair,
  })  : keyPair = keyPair,
        super(key: key);

  final PKCS12KeyPair keyPair;
  final String title;

  @override
  _EncryptAndDecryptOAEPBytesState createState() =>
      _EncryptAndDecryptOAEPBytesState();
}

class _EncryptAndDecryptOAEPBytesState
    extends State<EncryptAndDecryptOAEPBytes> {
  String _encrypted = "";
  String _decrypted = "";

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: const EdgeInsets.all(10),
      child: Card(
        child: Column(
          children: [
            TitleWidget(widget.title),
            InputWidget(
              title: "Encrypt",
              key: Key("encrypt"),
              result: _encrypted,
              onPressed: (controller) async {
                var encrypted = await RSA.encryptOAEPBytes(
                  Uint8List.fromList(controller.text.codeUnits),
                  "",
                  RSAHash.sha256,
                  widget.keyPair.publicKey,
                );
                setState(() {
                  _encrypted = base64Encode(encrypted);
                });
              },
            ),
            ButtonWidget(
              title: "Decrypt",
              key: Key("decrypt"),
              result: _decrypted,
              onPressed: () async {
                var decrypted = await RSA.decryptOAEPBytes(
                  base64Decode(_encrypted),
                  "",
                  RSAHash.sha256,
                  widget.keyPair.privateKey,
                );
                setState(() {
                  _decrypted = String.fromCharCodes(decrypted);
                });
              },
            ),
          ],
        ),
      ),
    );
  }
}

==> fast_rsa-2.0.1.tar.gz: example/lib/encrypt_decrypt_oaep_bytes.dart <==
import 'dart:convert';
import 'dart:typed_data';

import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:fast_rsa/rsa.dart';
import 'package:fast_rsa/model/bridge.pb.dart';
import 'package:rsa_example/main.dart';
import 'package:rsa_example/shared/button_widget.dart';
import 'package:rsa_example/shared/input_widget.dart';
import 'package:rsa_example/shared/title_widget.dart';

class EncryptAndDecryptOAEPBytes extends StatefulWidget {
  const EncryptAndDecryptOAEPBytes({
    Key? key,
    required this.title,
    required PKCS12KeyPair keyPair,
  })   : keyPair = keyPair,
        super(key: key);

  final PKCS12KeyPair keyPair;
  final String title;

  @override
  _EncryptAndDecryptOAEPBytesState createState() =>
      _EncryptAndDecryptOAEPBytesState();
}

class _EncryptAndDecryptOAEPBytesState
    extends State<EncryptAndDecryptOAEPBytes> {
  String _encrypted = "";
  String _decrypted = "";

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: const EdgeInsets.all(10),
      child: Card(
        child: Column(
          children: [
            TitleWidget(widget.title),
            InputWidget(
              title: "Encrypt",
              key: Key("encrypt"),
              result: _encrypted,
              onPressed: (controller) async {
                var encrypted = await RSA.encryptOAEPBytes(
                  Uint8List.fromList(controller.text.codeUnits),
                  "",
                  Hash.HASH_SHA256,
                  widget.keyPair.publicKey,
                );
                setState(() {
                  _encrypted = base64Encode(encrypted);
                });
              },
            ),
            ButtonWidget(
              title: "Decrypt",
              key: Key("decrypt"),
              result: _decrypted,
              onPressed: () async {
                var decrypted = await RSA.decryptOAEPBytes(
                  base64Decode(_encrypted),
                  "",
                  Hash.HASH_SHA256,
                  widget.keyPair.privateKey,
                );
                setState(() {
                  _decrypted = String.fromCharCodes(decrypted);
                });
              },
            ),
          ],
        ),
      ),
    );
  }
}
